@@ -35,7 +35,6 @@ private Q_SLOTS:
     void shouldAlignRight();
     void shouldAlignJustify();
     void shouldHaveDefaultValue();
-    void shouldAddQuote();
     void shouldBoldText();
     void shouldItalicText();
     void shouldTextUnderline();
@@ -47,6 +46,14 @@ private Q_SLOTS:
     void shouldTextSuperScript();
     void shouldTextSubScript();
 
+    void shouldRemoveQuote_data();
+    void shouldRemoveQuote();
+
+    void shouldRemoveQuoteWithSpecificQuote_data();
+    void shouldRemoveQuoteWithSpecificQuote();
+
+    void shouldAddQuote_data();
+    void shouldAddQuote();
 };
 
 #endif // RICHTEXTCOMPOSERCONTROLERTEST_H
