@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -26,7 +26,7 @@ class RichTextEditorTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit RichTextEditorTest(QObject *parent = Q_NULLPTR);
+    explicit RichTextEditorTest(QObject *parent = nullptr);
     ~RichTextEditorTest();
 
 private Q_SLOTS:
